@@ -66,10 +66,10 @@ def getTotalAmtDue(text: str):
         totalrow = re.sub(r'[^0-9|\.|\s|\$]', "", trowraw)
         if len(totalrow.split("$")[-1])>5:
             totalrow = totalrow.split(" . ")[0]
-        tdue = totalrow.split("$")[1].strip().replace("$","").replace(",","").replace(" ","").astype(float)
+        tdue = totalrow.split("$")[1].strip().replace("$","").replace(",","").replace(" ","")
     except IndexError:
-        tbal = np.nan
-    return tbal
+        tdue = ""
+    return tdue
 def getAddress(text: str):
     try:
         street_addr = re.search(r'(Address 1\:)(.+)(?:Phone)*?', str(text), re.MULTILINE).group(2).strip()
@@ -314,10 +314,9 @@ def getTotalBalance(text: str):
         if len(totalrow.split("$")[-1])>5:
             totalrow = totalrow.split(" . ")[0]
         tbal = totalrow.split("$")[3].strip().replace("$","").replace(",","").replace(" ","")
-        tbal = float(tbal)
     except:
-        tbal = np.nan
-    return tbal
+        tbal = ""
+    return str(tbal)
 def getPaymentToRestore(text: str):
     totalrow = "".join(re.findall(r'(Total.*\$.+\$.+\$.+)', str(text), re.MULTILINE)) if bool(re.search(r'(Total.*\$.*)', str(text), re.MULTILINE)) else "0"
     try:
@@ -334,7 +333,7 @@ def getPaymentToRestore(text: str):
     except (IndexError, TypeError):
         d999 = 0.0
     t_out = pd.Series(tbal - d999).astype(float).values[0]
-    return t_out
+    return str(t_out)
 def getBalanceByCode(text: str, code: str):
     actives = re.findall(r'(ACTIVE.*\$.*)', str(text))
     fees = pd.Series(actives,dtype=str)
@@ -348,7 +347,7 @@ def getBalanceByCode(text: str, code: str):
     'Balance': balancerows
     })
     matches = codemap[codemap.Code==code].Balance
-    return matches.sum()
+    return str(matches.sum())
 def getAmtDueByCode(text: str, code: str):
     actives = re.findall(r'(ACTIVE.*\$.*)', str(text))
     fees = pd.Series(actives,dtype=str)
@@ -368,7 +367,7 @@ def getAmtDueByCode(text: str, code: str):
     codemap.AmtDue = codemap.AmtDue.map(lambda x: pd.to_numeric(x,'coerce'))
 
     due = codemap.AmtDue[codemap.Code == code]
-    return due 
+    return str(due)
 def getAmtPaidByCode(text: str, code: str):
     actives = re.findall(r'(ACTIVE.*\$.*)', str(text))
     fees = pd.Series(actives,dtype=str)
@@ -388,7 +387,7 @@ def getAmtPaidByCode(text: str, code: str):
     codemap.AmtPaid = codemap.AmtPaid.map(lambda x: pd.to_numeric(x,'coerce'))
 
     paid = codemap.AmtPaid[codemap.Code == code]
-    return paid
+    return str(paid)
 def getCharges(text: str):
     cnum = getCaseNumber(text)
     rc = re.findall(r'(\d{3}\s{1}.{1,1000}?.{3}-.{3}-.{3}.{10,75})', text, re.MULTILINE)
@@ -524,46 +523,46 @@ def getCharges(text: str):
         charges = np.nan
 
     return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes, conv_codes, allcharge, charges]
-def getConvictions(text) -> str:
+def getConvictions(text):
     return getCharges(text)[0]
-def getDispositionCharges(text) -> str:
+def getDispositionCharges(text):
     return getCharges(text)[1]
-def getFilingCharges(text) -> str:
+def getFilingCharges(text) :
     return getCharges(text)[2]
-def getCERVConvictions(text) -> str:
+def getCERVConvictions(text):
     return getCharges(text)[3]
-def getPardonConvictions(text) -> str:
+def getPardonDQConvictions(text):
     return getCharges(text)[4]
-def getPermanentConvictions(text) -> str:
+def getPermanentDQConvictions(text):
     return getCharges(text)[5]
-def getConvictionCount(text) -> int:
+def getConvictionCount(text):
     return getCharges(text)[6]
-def getChargeCount(text) -> int:
+def getChargeCount(text):
     return getCharges(text)[7]
-def getCERVChargeCount(text) -> int:
+def getCERVChargeCount(text):
     return getCharges(text)[8]
-def getPardonDQCount(text) -> int:
+def getPardonDQCount(text):
     return getCharges(text)[9]
-def getPermanentDQChargeCount(text) -> int:
+def getPermanentDQChargeCount(text):
     return getCharges(text)[10]
-def getCERVConvictionCount(text) -> int:
+def getCERVConvictionCount(text):
     return getCharges(text)[11]
-def getPardonDQConvictionCount(text) -> int:
+def getPardonDQConvictionCount(text):
     return getCharges(text)[12]
-def getPermanentDQConvictionCount(text) -> int:
+def getPermanentDQConvictionCount(text):
     return getCharges(text)[13]
-def getChargeCodes(text) -> [str]:
+def getChargeCodes(text):
     return getCharges(text)[14]
-def getConvictionCodes(text) -> [str]:
+def getConvictionCodes(text):
     return getCharges(text)[15]
-def getChargesString(text) -> str:
+def getChargesString(text):
     return getCharges(text)[16]
 # config()
-def config(input_path, table_path=None, archive_path=None, text_path=None, table="", print_log=True, verbose=False, warn=False, max_cases=0, overwrite=True, GUI_mode=False, drop_cols=True, repeat_duplicates=True, launch=False, no_write=False, mk_archive=False): 
-
+def config(input_path, table_path=None, archive_path=None, text_path=None, table="", print_log=True, warn=False, max_cases=0, overwrite=True, GUI_mode=False, drop_cols=True, dedupe=False, launch=False, no_write=False, mk_archive=False, pager=False, drop=""): 
     tab_ext = ""
     arc_ext = ""
     in_ext = ""
+    input_type = ""
     appendArchive = False
     appendTable = False
     stringInput = True
@@ -573,24 +572,18 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
     launch = True if GUI_mode == True else launch
     if warn == False:
         warnings.filterwarnings("ignore")
+    if table_path == None and archive_path == None:
+        no_write = True
 ## INPUT
- # OBJECT INPUT
+ # Correct archive path provided as table path
     if table_path != None:
         if os.path.splitext(table_path)[1] == ".xz" and archive_path == None:
             archive_path = table_path
             table_path = None
-            if log:
+            if print_log and warn:
                 click.echo(f"WARNING: alac.config() received archive file format for parameter table_path: Setting archive_path to {archive_path}. Reconfigure to export table.")
-    if isinstance(input_path, pd.core.series.Series) or isinstance(input_path, pd.core.frame.DataFrame):
-        obj_in = input_path
-        input_path = ""
-        if "AllPagesText" in obj_in.columns:
-            pathMode = False
-            queue = obj_in['AllPagesText']
-        else:
-            raise Exception("Object input only supports archives! Must use \'AllPagesText\' series to continue.")
  # EXISTING FILE INPUT
-    elif os.path.isfile(input_path): 
+    if os.path.isfile(input_path): 
         in_head = os.path.split(input_path)[0]
         in_tail = os.path.split(input_path)[1]
         in_ext = os.path.splitext(input_path)[1]
@@ -598,13 +591,16 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
             try:
                 queue = pd.read_pickle(input_path,compression="xz")['AllPagesText']
                 pathMode = False
+                input_type = "archive"
             except KeyError:
                 raise Exception("Could not identify Series \'AllPagesText\' in input archive!")
         elif in_ext == ".pdf": # if pdf get text
             queue = pd.Series([getPDFText(input_path)])
             pathMode = False
+            input_type = "pdf"
         elif in_ext == ".txt": # if txt get text
             pathMode = False
+            input_type = "text"
             with open(input_path,'r') as textfile:
                 queue = pd.Series([textfile.read()])
         else:
@@ -612,6 +608,7 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
  # DIRECTORY INPUT
     elif os.path.isdir(input_path):
         queue = pd.Series(glob.glob(input_path + '**/*.pdf', recursive=True))
+        input_type = "directory"
         pathMode = True
         if queue.shape[0] == 0:
             raise Exception("No PDFs found in input directory!")
@@ -657,11 +654,15 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         if arc_ext == ".xz": # if archive 
             try: # if exists at path, append
                 old_archive = pd.read_pickle(archive_path,compression="xz")
+                if print_log:
+                    try:
+                        click.echo(old_archive.columns)
+                    except:
+                        pass
                 appendArchive = True
             except: 
                 pass
-        #else:
-         #   raise Exception("Invalid file extension! Archives must export to .pkl.xz")
+
 ## TABLE OUT 
     if table_path != None:
         tab_head = os.path.split(table_path)[0]
@@ -677,6 +678,9 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
                     old_fees = pd.read_excel(table_path, sheet_name="fees")
                     old_charges = pd.read_excel(table_path, sheet_name="charges")
                     old_table = [old_cases, old_fees, old_charges]
+                    if print_log:
+                        for x in old_table:
+                            click.echo(f"Existing table at output with columns: {x.columns}")
                 except:
                     appendTable = False
                     pass
@@ -687,11 +691,11 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
             elif tab_ext == ".dta":
                 old_table = pd.read_stata(table_path)
             elif overwrite:
-                if warn:
-                    appendTable = False
-                    click.echo("WARNING: FORCE OVERWRITE MODE IS ENABLED. EXISTING FILE AT TABLE OUTPUT PATH WILL BE OVERWRITTEN.")
+                appendTable = False
+                if print_log:
+                    click.confirm("WARNING: Force overwrite mode is enabled. Existing file at table output path will be overwritten. Continue anyway?")
             else:
-                raise Exception("Existing file at output path! Provide valid table export path or use \'overwrite\' flag to replace existing file with task outputs.")
+                raise Exception("ERROR: Existing file at output path! Provide valid table export path or use \'overwrite\' flag to replace existing file with task outputs.")
         elif os.path.exists(tab_head) == False or (tab_ext == ".xz" or tab_ext == ".pkl" or tab_ext == ".json" or tab_ext == ".csv" or tab_ext == ".txt" or tab_ext == ".xls" or tab_ext == ".xlsx" or tab_ext == ".dta") == False:
             raise Exception("Table output invalid!")
         elif table == "" and tab_ext != ".xls" and tab_ext != ".xlsx" and tab_ext != ".pkl" and tab_ext != ".xz":
@@ -701,21 +705,17 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         else:
             raise Exception("Invalid table output file extension! Must write to .xls, .xlsx, .csv, .json, or .dta.")
 ## LOG INPUT 
-    if print_log == True and verbose == True:
-        if table_path == None and archive_path == None:
-            if GUI_mode == False:
-                click.echo(f"\nNo output path provided. alac.parse...() functions will {'print to console and' if print_log else ''} return object.")
-            if GUI_mode == True:
-                raise Exception(f"No output path provided! Use alac libraries without guided interface to return object to python.")
-        if content_length > max_cases:
-            click.echo(f"\n>>    INPUT:  {max_cases} of {content_length} total {'paths' if pathMode else 'cases'} loaded from input: {input_path}")
-        if content_length <= max_cases:
-            click.echo(f"\n>>    INPUT:  {max_cases} {'paths' if pathMode else 'cases'} loaded from input: {input_path if pathMode else ''}")
-        if table_path != None:
-            click.echo(f">>    TABLE:  {'cases, charges, fees' if table == '' else table} to {table_path}")
-        if archive_path != None:
-            click.echo(f">>    ARCHIVE:  {'cases, charges, fees' if table == '' else table} to {'existing archive at: ' if appendArchive else ''}{archive_path}\n\n")
-## OBJECT
+    if print_log:
+            click.echo(f"""
+Configured!
+Writing {table}{'(except '+drop+') ' if len(drop)>0 else ''}from {input_type} {input_path} to {table_path if mk_archive == False else archive_path}
+Queued {max_cases} cases of {content_length} for export to {table_path if mk_archive == False else archive_path}
+{"OVERWRITE MODE is enabled. Alacorder will overwrite existing files at output path!" if overwrite else 'Overwrite mode is not enabled.'}
+{"APPEND MODE is enabled. Alacorder will attempt to append outputs to existing file at path." if overwrite == False and (appendTable == True or appendArchive == True) else 'Append mode is not enabled.'}
+{"NO-WRITE MODE is enabled. Alacorder will NOT export outputs." if no_write else 'No-Write mode (--no-write) is not enabled.'}
+{"REMOVE DUPLICATES is enabled. At time of export, all duplicate cases will be removed from output." if dedupe else 'Remove Duplicates (--dedupe) is not enabled.'}
+{"LAUNCH MODE is enabled. Upon completion, Alacorder will attempt to launch exported file in default viewing application." if launch else 'Launch mode (--launch) is not enabled.'}
+{"PAGER MODE is enabled. Upon completion, Alacorder will load outputs to console." if pager else 'Pager mode (--pager) is not enabled.'}""")
     return pd.Series({
         'input_path': input_path,
         'table_out': table_path,
@@ -729,16 +729,20 @@ def config(input_path, table_path=None, archive_path=None, text_path=None, table
         'old_table': old_table,
         'warn': warn, 
         'log': print_log,
-        'verbose': verbose, 
         'overwrite': overwrite,
         'queue': queue,
         'count': max_cases, 
         'path_mode': pathMode,
         'drop_cols': drop_cols,
+        'drop': drop,
+        'pager': pager,
+        'dedupe': dedupe,
         'launch': launch,
         'no_write': no_write,
         'mk_archive': mk_archive
         })
+
+
 def splitext(path: str):
     head = os.path.split(path)[0]
     tail = os.path.split(path)[1]
@@ -748,7 +752,7 @@ def splitext(path: str):
         'tail': tail,
         'ext': ext
     })
-def checkPath(path: str, log=True):
+def checkPath(path: str, warn=False):
     PathType = ""
     if os.path.isdir(path):
         count = len(glob.glob(path + '**/*.pdf', recursive=True))
@@ -757,7 +761,7 @@ def checkPath(path: str, log=True):
             warnings.warn("No PDFs found in input path!")
         if count > 0:
             PathType = "pdf_directory"
-            if log:
+            if warn:
                 click.echo(f"\nAlacorder found {count} PDFs in input directory.")
             return PathType
     else:
@@ -773,7 +777,7 @@ def checkPath(path: str, log=True):
         if os.path.isfile(path):
             if ext == ".txt":
                 PathType = "text"
-                if log:
+                if warn:
                     click.echo(f"WARNING: text file input experimental!")
             if ext == ".pdf":
                 PathType = "pdf"
@@ -781,29 +785,29 @@ def checkPath(path: str, log=True):
                 test = pd.read_pickle(path,compression="xz")
                 if "AllPagesText" in test.columns:
                     PathType = "existing_archive"
-                    if log:
+                    if warn:
                         click.echo(f"Found existing archive with {test.shape[0]} cases.")
                     return PathType
                 else:
                     PathType = "overwrite_archive"
-                    if log:
+                    if warn:
                         click.echo("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                     return PathType
             elif ext == ".xls" or ext == ".xlsx":
-                if log:
+                if warn:
                     click.echo("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                 PathType = "overwrite_all_table"
                 return PathType
             elif ext == ".csv" or ext == ".json" or ext == ".dta":
-                if log:
+                if warn:
                     click.echo("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                 PathType = "overwrite_table"
                 return PathType
             else:
                 PathType = "bad"
-                if log:
+                if warn:
                     click.echo("Output file extension not supported!")
-                if log:
+                if warn:
                     click.echo("WARNING: Existing file at archive output cannot be parsed and will be overwritten!")
                 return PathType
         else:
@@ -826,12 +830,12 @@ def write(conf, outputs, archive=False):
     old_archive = conf['old_archive']
     old_table = conf['old_table']
     appendTable = conf['appendTable']
+    print_log = conf['log']
 
     if appendTable and isinstance(old_table, pd.core.frame.DataFrame):
         # print(outputs.info())
         out = [outputs, old_table]
         outputs = pd.concat(out)
-        print(outputs.info())
 
     if isinstance(old_archive, pd.core.frame.DataFrame):
         try:
@@ -919,31 +923,41 @@ def writeArchive(conf):
     old_archive = conf['old_archive']
     overwrite = conf['overwrite']
     no_write = conf['no_write']
+    dedupe = conf['dedupe']
     start_time = time.time()
     if warn == False:
         warnings.filterwarnings("ignore")
 
-    if path_mode:
-        allpagestext = pd.Series(queue).map(lambda x: getPDFText(x))
-    else:
-        allpagestext = queue
+    if dedupe == True:
+        queue = queue.drop_duplicates()
 
-    outputs = pd.DataFrame({
-        'Path': queue if path_mode else np.nan,
-        'AllPagesText': allpagestext,
-        'Timestamp': start_time
-        })
+    batches = pd.Series(np.array_split(queue, math.ceil(max_cases / 500)))
+    batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+    with click.progressbar(batches) as bar:
+        for i, c in enumerate(bar):
+            if path_mode:
+                allpagestext = pd.Series(c).map(lambda x: getPDFText(x))
+            else:
+                allpagestext = c
 
-    if isinstance(old_archive, pd.core.frame.DataFrame):
-        try:
-            outputs = old_archive.append(outputs)
-        except:
-            outputs = [old_archive, outputs]
+            outputs = pd.DataFrame({
+                'Path': queue if path_mode else np.nan,
+                'AllPagesText': allpagestext,
+                'Timestamp': start_time
+                })
 
-    outputs.fillna('',inplace=True)
+            if isinstance(old_archive, pd.core.frame.DataFrame):
+                try:
+                    outputs = old_archive.append(outputs)
+                except:
+                    outputs = [old_archive, outputs]
+        outputs.fillna('',inplace=True)
+
+    if dedupe == True:
+            outputs = outputs.drop_duplicates()
     if not no_write:
         write(conf, outputs, archive=True)
-    log_complete(conf, start_time)
+    log_complete(conf, start_time, outputs)
     return outputs
 def parseFees(conf):
     path_in = conf['input_path']
@@ -994,7 +1008,7 @@ def parseFees(conf):
             fees['AmtHold'] = fees['AmtHold'].map(lambda x: pd.to_numeric(x,'coerce'))
     if not no_write:
         write(conf, fees)
-    log_complete(conf, start_time)
+    log_complete(conf, start_time, fees)
     return fees
 def parseCharges(conf):
     path_in = conf['input_path']
@@ -1049,8 +1063,8 @@ def parseCharges(conf):
                 charges = charges[is_disp]
         if not no_write:
             write(conf, charges)
-    log_complete(conf, start_time)
 
+    log_complete(conf, start_time, charges)
     return charges
 def parseCases(conf):
     path_in = conf['input_path']
@@ -1187,6 +1201,7 @@ def parseCases(conf):
             b.fillna('',inplace=True)
             charges.fillna('',inplace=True)
             fees.fillna('',inplace=True)
+            cases.fillna('',inplace=True)
             newcases = [cases, b]
             cases = cases.append(newcases, ignore_index=True)
             charges = charges[['CaseNumber', 'Num', 'Code', 'Description', 'Cite', 'CourtAction', 'CourtActionDate', 'Category', 'TypeDescription', 'Disposition', 'Permanent', 'Pardon', 'CERV','Conviction']]
@@ -1259,7 +1274,7 @@ def parseCases(conf):
                     cases.to_stata(path_out)
                 else:
                     pd.Series([cases, fees, charges]).to_string(path_out)
-        log_complete(conf, start_time)
+        log_complete(conf, start_time, pd.Series([cases, fees, charges]).to_string())
         return [cases, fees, charges]
 def parseCaseInfo(conf):
     path_in = conf['input_path']
@@ -1326,9 +1341,9 @@ def parseCaseInfo(conf):
             # write 
         if not no_write:
             write(conf, cases)
-        log_complete(conf, start_time)
+        log_complete(conf, start_time, cases)
         return cases
-def parse(conf, method, *args):
+def parse(conf, *args):
     path_in = conf['input_path']
     path_out = conf['table_out']
     max_cases = conf['count']
@@ -1348,71 +1363,74 @@ def parse(conf, method, *args):
     uselist = False
     func = pd.Series(args).map(lambda x: 1 if inspect.isfunction(x) else 0)
     funcs = func.index.map(lambda x: args[x] if func[x]>0 else np.nan)
-    funcs = funcs.dropna()
     no_funcs = func.index.map(lambda x: args[x] if func[x]==0 else np.nan)
     no_funcs = no_funcs.dropna()
     countfunc = func.sum()
     column_getters = pd.DataFrame(columns=['Name','Method','Arguments'],index=(range(0,countfunc)))
     df_out = pd.DataFrame()
-
     local_get = []
-
-
     for i, x in enumerate(funcs):
         if inspect.isfunction(x):
             column_getters.Name[i] = x.__name__
             column_getters.Method[i] = x
-
     for i, x in enumerate(args):
         if inspect.isfunction(x) == False:
             column_getters.Arguments.iloc[i-1] = x
-
+    if print_log:
+        click.echo(column_getters)
     def ExceptionWrapperArgs(mfunc, x, *args):
         unpacked_args = args
         a = mfunc(x, unpacked_args)
         return a
 
     def ExceptionWrapper(mfunc, x):
-        a = mfunc(x)
+        a = str(mfunc(x))
         return a
-
+    temp_no_write_tab = False
     with click.progressbar(batches) as bar:
         for i, c in enumerate(bar):
             exptime = time.time()
             b = pd.DataFrame()
 
+            if bool(path_out) and i > 0 and not no_write:
+                if os.path.getsize(path_out) > 500:
+                    temp_no_write_tab = True
+            if i == len(batches) - 1:
+                temp_no_write_tab = False
             if from_archive == True:
                 allpagestext = c
             else:
                 allpagestext = pd.Series(c).map(lambda x: getPDFText(x))
             df_out['CaseNumber'] = allpagestext.map(lambda x: getCaseNumber(x))
             for i, getter in enumerate(column_getters.Method.tolist()):
-                arg = pd.Series(column_getters.Arguments.tolist()[i])
-                #try:
-                if not arg.any():
-                    name = getter.__name__
+                arg = column_getters.Arguments[i]
+                try:
+                    name = getter.__name__.strip()[3:]
                     col = pd.DataFrame({
-                        name: allpagestext.map(lambda x: ExceptionWrapper(getter, x))
-                        })
-                else:
-                    name = getter.__name__
-                    col = pd.DataFrame({
-                        name: allpagestext.map(lambda x: ExceptionWrapperArgs(getter, x, arg))
+                    name: allpagestext.map(lambda x: getter(x, arg))
                         })
+                except (AttributeError,TypeError):
+                    try:
+                        name = getter.__name__.strip()[3:]
+                        col = pd.DataFrame({
+                        name: allpagestext.map(lambda x: getter(x))
+                                })
+                    except (AttributeError,TypeError):
+                        name = getter.__name__.strip()[2:-1]
+                        col = pd.DataFrame({
+                        name: allpagestext.map(lambda x: ExceptionWrapper(x,arg))
+                                })
                 n_out = [df_out, col]
-                df_out = pd.concat(n_out,axis=1)
+                df_out = pd.concat([df_out,col.reindex(df_out.index)],axis=1)
+                df_out = df_out.dropna(axis=1)
+                df_out = df_out.convert_dtypes()
 
-            if no_write == False and (i % 5 == 0 or i == len(batches) - 1):
+            if no_write == False and temp_no_write_tab == False and (i % 5 == 0 or i == len(batches) - 1):
                 write(conf, df_out) # rem alac
     if not no_write:
         write(conf, df_out) # rem alac
-    allout = df_out.infer_objects()
-    try:
-        allout = allout.map(lambda x: x.values[0])
-    except AttributeError:
-        pass
-    log_complete(conf, start_time)
-    return allout
+    log_complete(conf, start_time, df_out)
+    return df_out
 
 ## LOG
 def log_complete(conf, start_time, output=None):
@@ -1421,39 +1439,25 @@ def log_complete(conf, start_time, output=None):
     arc_out = conf['archive_out']
     print_log = conf['log']
     max_cases = conf['count']
-    verbose = conf['verbose']
     launch = conf['launch']
+    pager = conf['pager']
     completion_time = time.time()
     elapsed = completion_time - start_time
     cases_per_sec = max_cases/elapsed
+    if pager:
+        click.echo_via_pager(output)
     if launch:
         time.sleep(5)
         click.launch(path_out)
     if print_log:
         click.clear()
-        click.echo(f'''
-    >>> TASK COMPLETED!
-        {">   INPUT: "+path_in if bool(path_in) else ""}
-        {">   OUTPUT: "+path_out if bool(path_out) else ""}
-        {">   ARCHIVE: "+arc_out if bool(arc_out) else ""}
-        Successfully processed {max_cases} cases.
-        Last batch completed in {elapsed:.2f} seconds ({cases_per_sec:.2f} cases/sec)
-        ''')
+        click.echo(f'''\nTASK COMPLETED: Successfully processed {max_cases} cases. Last batch completed in {elapsed:.2f} seconds ({cases_per_sec:.2f} cases/sec)''')
 def log_console(conf, *msg):
     path_in = conf['input_path']
     path_out = conf['table_out']
     arc_out = conf['archive_out']
     print_log = conf['log']
     max_cases = conf['count']
-    verbose = conf['verbose']
     click.clear()
     if print_log:
         click.echo(msg)
-        click.echo(f'''
-    >>  ALACORDER IN PROGRESS:
-        {">   INPUT: "+path_in if bool(path_in) else ""}
-        {">   OUTPUT: "+path_out if bool(path_out) else ""}
-        {">   ARCHIVE: "+arc_out if bool(arc_out) else ""}
-        ''')
-
-
